@@ -1,4 +1,4 @@
 from muse_maskgit_pytorch.vqgan_vae import VQGanVAE
-from muse_maskgit_pytorch.muse_maskgit_pytorch import Transformer, MaskGit, Muse
+from muse_maskgit_pytorch.muse_maskgit_pytorch import Transformer, MaskGit, Muse, MaskGitTransformer, TokenCritic
 
 from muse_maskgit_pytorch.trainers import VQGanVAETrainer
